@@ -40,6 +40,7 @@
 
 #include "gtkintl.h"
 #include "gtkprivate.h"
+#include "gtkbuildable.h"
 
 #include "gtkalias.h"
 
@@ -119,6 +120,23 @@ static void     gtk_assistant_get_child_property (GtkContainer      *container,
 
 static AtkObject *gtk_assistant_get_accessible   (GtkWidget         *widget);
 
+static void       gtk_assistant_buildable_interface_init     (GtkBuildableIface *iface);
+static GObject   *gtk_assistant_buildable_get_internal_child (GtkBuildable  *buildable,
+                                                              GtkBuilder    *builder,
+                                                              const gchar   *childname);
+static gboolean   gtk_assistant_buildable_custom_tag_start   (GtkBuildable  *buildable,
+                                                              GtkBuilder    *builder,
+                                                              GObject       *child,
+                                                              const gchar   *tagname,
+                                                              GMarkupParser *parser,
+                                                              gpointer      *data);
+static void       gtk_assistant_buildable_custom_finished    (GtkBuildable  *buildable,
+                                                              GtkBuilder    *builder,
+                                                              GObject       *child,
+                                                              const gchar   *tagname,
+                                                              gpointer       user_data);
+
+
 enum
 {
   CHILD_PROP_0,
@@ -141,7 +159,9 @@ enum
 static guint signals [LAST_SIGNAL] = { 0 };
 
 
-G_DEFINE_TYPE (GtkAssistant, gtk_assistant, GTK_TYPE_WINDOW)
+G_DEFINE_TYPE_WITH_CODE (GtkAssistant, gtk_assistant, GTK_TYPE_WINDOW,
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE,
+                                                gtk_assistant_buildable_interface_init))
 
 
 static void
@@ -197,7 +217,7 @@ gtk_assistant_class_init (GtkAssistantClass *class)
    * @assistant: the #GtkAssistant
    * @page: the current page
    *
-   * The ::prepare signal is emitted when a new page is set as the assistant's
+   * The ::prepared signal is emitted when a new page is set as the assistant's
    * current page, before making the new page visible. A handler for this signal
    * can do any preparation which are necessary before showing @page.
    *
@@ -217,14 +237,14 @@ gtk_assistant_class_init (GtkAssistantClass *class)
    * @assistant: the @GtkAssistant
    *
    * The ::apply signal is emitted when the apply button is clicked. The default
-   * behavior of the #GtkAssistant is to switch to the page after the current
-   * page, unless the current page is the last one.
+   * behavior of the #GtkAssistant is to switch to the page after the current page,
+   * unless the current page is the last one.
    *
-   * A handler for the ::apply signal should carry out the actions for which
-   * the wizard has collected data. If the action takes a long time to complete,
-   * you might consider to put a page of type %GTK_ASSISTANT_PAGE_PROGRESS
-   * after the confirmation page and handle this operation within the
-   * #GtkAssistant::prepare signal of the progress page.
+   * A handler for the ::apply signal should carry out the actions for which the
+   * wizard has collected data. If the action takes a long time to complete, you
+   * might consider to put a page of type GTK_ASSISTANT_PAGE_PROGRESS after the
+   * confirmation page and handle this operation within the ::prepare signal of
+   * the progress page.
    *
    * Since: 2.10
    */
@@ -243,7 +263,7 @@ gtk_assistant_class_init (GtkAssistantClass *class)
    *
    * The ::close signal is emitted either when the close button of
    * a summary page is clicked, or when the apply button in the last
-   * page in the flow (of type %GTK_ASSISTANT_PAGE_CONFIRM) is clicked.
+   * page in the flow (of type GTK_ASSISTANT_PAGE_CONFIRM) is clicked.
    *
    * Since: 2.10
    */
@@ -276,7 +296,7 @@ gtk_assistant_class_init (GtkAssistantClass *class)
   /**
    * GtkAssistant:page-type:
    *
-   * The type of the assistant page.
+   * The type of the assistant page. 
    *
    * Since: 2.10
    */
@@ -292,7 +312,7 @@ gtk_assistant_class_init (GtkAssistantClass *class)
   /**
    * GtkAssistant:title:
    *
-   * The title that is displayed in the page header.
+   * The title that is displayed in the page header. 
    *
    * If title and header-image are both %NULL, no header is displayed.
    *
@@ -326,7 +346,7 @@ gtk_assistant_class_init (GtkAssistantClass *class)
   /**
    * GtkAssistant:header-image:
    *
-   * The image that is displayed next to the page.
+   * The image that is displayed next to the page. 
    *
    * Set this to %NULL to make the sidebar disappear.
    *
@@ -410,12 +430,14 @@ compute_last_button_state (GtkAssistant *assistant)
       page_info = g_list_nth_data (priv->pages, page_num);
 
       count++;
+
+      g_assert (page_info);
     }
 
   /* make the last button visible if we can skip multiple
-   * pages and end on a confirmation or summary page
+   * pages and end on a confirmation or summary page 
    */
-  if (count > 1 && page_info &&
+  if (count > 1 && 
       (page_info->type == GTK_ASSISTANT_PAGE_CONFIRM ||
        page_info->type == GTK_ASSISTANT_PAGE_SUMMARY))
     {
@@ -463,7 +485,6 @@ set_assistant_buttons_state (GtkAssistant *assistant)
     case GTK_ASSISTANT_PAGE_INTRO:
       gtk_widget_set_sensitive (assistant->cancel, TRUE);
       gtk_widget_set_sensitive (assistant->forward, priv->current_page->complete);
-      gtk_widget_grab_default (assistant->forward);
       gtk_widget_show (assistant->cancel);
       gtk_widget_show (assistant->forward);
       gtk_widget_hide (assistant->back);
@@ -475,7 +496,6 @@ set_assistant_buttons_state (GtkAssistant *assistant)
       gtk_widget_set_sensitive (assistant->cancel, TRUE);
       gtk_widget_set_sensitive (assistant->back, TRUE);
       gtk_widget_set_sensitive (assistant->apply, priv->current_page->complete);
-      gtk_widget_grab_default (assistant->apply);
       gtk_widget_show (assistant->cancel);
       gtk_widget_show (assistant->back);
       gtk_widget_show (assistant->apply);
@@ -487,7 +507,6 @@ set_assistant_buttons_state (GtkAssistant *assistant)
       gtk_widget_set_sensitive (assistant->cancel, TRUE);
       gtk_widget_set_sensitive (assistant->back, TRUE);
       gtk_widget_set_sensitive (assistant->forward, priv->current_page->complete);
-      gtk_widget_grab_default (assistant->forward);
       gtk_widget_show (assistant->cancel);
       gtk_widget_show (assistant->back);
       gtk_widget_show (assistant->forward);
@@ -497,7 +516,6 @@ set_assistant_buttons_state (GtkAssistant *assistant)
       break;
     case GTK_ASSISTANT_PAGE_SUMMARY:
       gtk_widget_set_sensitive (assistant->close, TRUE);
-      gtk_widget_grab_default (assistant->close);
       gtk_widget_show (assistant->close);
       gtk_widget_hide (assistant->cancel);
       gtk_widget_hide (assistant->back);
@@ -509,7 +527,6 @@ set_assistant_buttons_state (GtkAssistant *assistant)
       gtk_widget_set_sensitive (assistant->cancel, priv->current_page->complete);
       gtk_widget_set_sensitive (assistant->back, priv->current_page->complete);
       gtk_widget_set_sensitive (assistant->forward, priv->current_page->complete);
-      gtk_widget_grab_default (assistant->forward);
       gtk_widget_show (assistant->cancel);
       gtk_widget_show (assistant->back);
       gtk_widget_show (assistant->forward);
@@ -625,10 +642,10 @@ on_assistant_apply (GtkWidget    *widget,
 {
   gboolean success;
 
-  g_signal_emit (assistant, signals [APPLY], 0);
-
   success = compute_next_step (assistant);
 
+  g_signal_emit (assistant, signals [APPLY], 0);
+
   /* if the assistant hasn't switched to another page, just emit
    * the CLOSE signal, it't the last page in the assistant flow
    */
@@ -737,9 +754,6 @@ gtk_assistant_init (GtkAssistant *assistant)
   assistant->back    = gtk_button_new_from_stock (GTK_STOCK_GO_BACK);
   assistant->cancel  = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
   assistant->last    = gtk_button_new_from_stock (GTK_STOCK_GOTO_LAST);
-  GTK_WIDGET_SET_FLAGS (assistant->close, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (assistant->apply, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (assistant->forward, GTK_CAN_DEFAULT);
 
   priv->size_group   = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
   gtk_size_group_add_widget (priv->size_group, assistant->close);
@@ -1210,7 +1224,6 @@ gtk_assistant_map (GtkWidget *widget)
   GtkAssistant *assistant = GTK_ASSISTANT (widget);
   GtkAssistantPrivate *priv = assistant->priv;
   GList *page_node;
-  GtkAssistantPage *page;
 
   GTK_WIDGET_SET_FLAGS (widget, GTK_MAPPED);
 
@@ -1222,8 +1235,7 @@ gtk_assistant_map (GtkWidget *widget)
     gtk_widget_map (priv->sidebar_image);
 
   /* if there's no default page, pick the first one */
-  page = NULL;
-  if (!priv->current_page)
+  if (!priv->current_page && priv->pages)
     {
       page_node = priv->pages;
 
@@ -1231,13 +1243,22 @@ gtk_assistant_map (GtkWidget *widget)
 	page_node = page_node->next;
 
       if (page_node)
-	page = page_node->data;
+	priv->current_page = page_node->data;
     }
 
-  if (page &&
-      GTK_WIDGET_VISIBLE (page->page) &&
-      !GTK_WIDGET_MAPPED (page->page))
-    set_current_page (assistant, page);
+  if (priv->current_page &&
+      GTK_WIDGET_VISIBLE (priv->current_page->page) &&
+      !GTK_WIDGET_MAPPED (priv->current_page->page))
+    {
+      set_assistant_buttons_state ((GtkAssistant *) widget);
+      set_assistant_header_image ((GtkAssistant*) widget);
+      set_assistant_sidebar_image ((GtkAssistant*) widget);
+
+      g_signal_emit (widget, signals [PREPARE], 0, priv->current_page->page);
+      gtk_widget_set_child_visible (priv->current_page->page, TRUE);
+      gtk_widget_map (priv->current_page->page);
+      gtk_widget_map (priv->current_page->title);
+    }
 
   GTK_WIDGET_CLASS (gtk_assistant_parent_class)->map (widget);
 }
@@ -2153,7 +2174,7 @@ gtk_assistant_set_page_complete (GtkAssistant *assistant,
  * @assistant: a #GtkAssistant
  * @page: a page of @assistant
  * 
- * Gets whether @page is complete.
+ * Gets whether @page is complete..
  * 
  * Return value: %TRUE if @page is complete.
  *
@@ -2232,7 +2253,7 @@ gtk_assistant_accessible_ref_child (AtkObject *accessible,
   GtkWidget *widget, *child;
   gint n_pages;
   AtkObject *obj;
-  gchar *title;
+  const gchar *title;
 
   widget = GTK_ACCESSIBLE (accessible)->widget;
   if (!widget)
@@ -2246,7 +2267,7 @@ gtk_assistant_accessible_ref_child (AtkObject *accessible,
     return NULL;
   else if (index < n_pages)
     {
-      GtkAssistantPage *page = g_list_nth_data (priv->pages, index);
+      GtkAssistantPage *page = g_list_nth_data (priv->pages, index / 2);
 
       child = page->page;
       title = gtk_assistant_get_page_title (assistant, child);
@@ -2289,15 +2310,15 @@ gtk_assistant_accessible_get_type (void)
       GType derived_type;
       GTypeQuery query;
       GType derived_atk_type;
-      
+
       derived_type = g_type_parent (GTK_TYPE_ASSISTANT);
       factory = atk_registry_get_factory (atk_get_default_registry (),
 					  derived_type);
       derived_atk_type = atk_object_factory_get_accessible_type (factory);
       g_type_query (derived_atk_type, &query);
-      
-      type = g_type_register_static_simple (derived_atk_type, 
-					    I_("GtkAssistantAccessible"), 
+
+      type = g_type_register_static_simple (derived_atk_type,
+					    I_("GtkAssistantAccessible"),
 					    query.class_size,
 					    (GClassInitFunc) gtk_assistant_accessible_class_init,
 					    query.instance_size,
@@ -2314,9 +2335,9 @@ gtk_assistant_accessible_new (GObject *obj)
 
   g_return_val_if_fail (GTK_IS_ASSISTANT (obj), NULL);
 
-  accessible = g_object_new (gtk_assistant_accessible_get_type (), NULL); 
+  accessible = g_object_new (gtk_assistant_accessible_get_type (), NULL);
   atk_object_initialize (accessible, obj);
-  
+
   return accessible;
 }
 
@@ -2344,16 +2365,16 @@ gtk_assistant_accessible_factory_get_type (void)
 {
   static GType type = 0;
 
-  if (!type) 
+  if (!type)
     {
-      type = g_type_register_static_simple (ATK_TYPE_OBJECT_FACTORY, 
+      type = g_type_register_static_simple (ATK_TYPE_OBJECT_FACTORY,
 					    I_("GtkAssistantAccessibleFactory"),
 					    sizeof (AtkObjectFactoryClass),
 					    (GClassInitFunc) gtk_assistant_accessible_factory_class_init,
 					    sizeof (AtkObjectFactory),
 					    NULL, 0);
     }
-  
+
   return type;
 }
 
@@ -2362,12 +2383,12 @@ gtk_assistant_get_accessible (GtkWidget *widget)
 {
   static gboolean first_time = TRUE;
 
-  if (first_time) 
+  if (first_time)
     {
       AtkObjectFactory *factory;
       AtkRegistry *registry;
-      GType derived_type; 
-      GType derived_atk_type; 
+      GType derived_type;
+      GType derived_atk_type;
 
       /*
        * Figure out whether accessibility is enabled by looking at the
@@ -2382,7 +2403,7 @@ gtk_assistant_get_accessible (GtkWidget *widget)
       derived_atk_type = atk_object_factory_get_accessible_type (factory);
       if (g_type_is_a (derived_atk_type, GTK_TYPE_ACCESSIBLE))
 	{
-	  atk_registry_set_factory_type (registry, 
+	  atk_registry_set_factory_type (registry,
 					 GTK_TYPE_ASSISTANT,
 					 gtk_assistant_accessible_factory_get_type ());
 	}
@@ -2393,5 +2414,53 @@ gtk_assistant_get_accessible (GtkWidget *widget)
 }
 
 
+static GtkBuildableIface *parent_buildable_iface;
+
+static void
+gtk_assistant_buildable_interface_init (GtkBuildableIface *iface)
+{
+  parent_buildable_iface = g_type_interface_peek_parent (iface);
+  iface->get_internal_child = gtk_assistant_buildable_get_internal_child;
+  iface->custom_tag_start = gtk_assistant_buildable_custom_tag_start;
+  iface->custom_finished = gtk_assistant_buildable_custom_finished;
+}
+
+static GObject *
+gtk_assistant_buildable_get_internal_child (GtkBuildable *buildable,
+                                            GtkBuilder   *builder,
+                                            const gchar  *childname)
+{
+    if (strcmp (childname, "action_area") == 0)
+      return G_OBJECT (GTK_ASSISTANT (buildable)->priv->action_area);
+
+    return parent_buildable_iface->get_internal_child (buildable,
+                                                       builder,
+                                                       childname);
+}
+
+gboolean
+gtk_assistant_buildable_custom_tag_start (GtkBuildable  *buildable,
+                                          GtkBuilder    *builder,
+                                          GObject       *child,
+                                          const gchar   *tagname,
+                                          GMarkupParser *parser,
+                                          gpointer      *data)
+{
+  return parent_buildable_iface->custom_tag_start (buildable, builder, child,
+                                                   tagname, parser, data);
+}
+
+static void
+gtk_assistant_buildable_custom_finished (GtkBuildable *buildable,
+                                         GtkBuilder   *builder,
+                                         GObject      *child,
+                                         const gchar  *tagname,
+                                         gpointer      user_data)
+{
+  parent_buildable_iface->custom_finished (buildable, builder, child,
+                                           tagname, user_data);
+}
+
+
 #define __GTK_ASSISTANT_C__
 #include "gtkaliasdef.c"
